@@ -13,8 +13,9 @@ from jinja2 import Environment
 
 from cloudinary_cli.defaults import logger, TEMPLATE_FOLDER
 
-not_callable = ('is_appengine_sandbox', 'call_tags_api', 'call_context_api', 'call_cacheable_api', 'call_api', 'text',
-                'account_config', 'reset_config')
+not_callable = ('is_appengine_sandbox', 'call_tags_api', 'call_context_api', 'call_cacheable_api', 'call_api',
+                'call_metadata_api', 'call_json_api', 'text', 'only', 'transformation_string'
+                'account_config', 'reset_config', 'upload_large_part')
 
 BLOCK_SIZE = 65536
 
@@ -154,3 +155,93 @@ def get_user_action(message, options):
     """
     r = input(message).lower()
     return options.get(r, options.get("default"))
+
+
+def get_command_params(
+        params,
+        optional_parameter,
+        optional_parameter_parsed,
+        module,
+        module_name):
+    method = params[0]
+    if method not in module.__dict__:
+        raise Exception(f"Method {params[0]} does not exist in {module_name.capitalize()}.")
+
+    func = module.__dict__.get(method)
+
+    if not callable(func):
+        raise Exception(f"{params[0]} is not callable.")
+
+    args, kwargs = parse_args_kwargs(func, params[1:]) if len(params) > 1 else ([], {})
+
+    kwargs = {
+        **kwargs,
+        **{k: v for k, v in optional_parameter},
+        **{k: parse_option_value(v) for k, v in optional_parameter_parsed},
+    }
+
+    return func, args, kwargs
+
+
+def whitelist_keys(data, keys):
+    """
+    Iterates over a list of dictionaries and keeps only the keys that were specified.
+
+    :param data: A list of dictionaries.
+    :type data: list
+    :param keys: a list of keys to keep in each dictionary.
+    :type keys: list
+
+    :return: The whitelisted list.
+    :rtype list
+    """
+    # no whitelist when fields are not provided or on a list of non-dictionary items.
+    if not keys or any(not isinstance(i, dict) for i in data):
+        return data
+
+    return list(
+        map(lambda x: {
+            k: x[k]
+            for k in keys if k in x},
+            data)
+    )
+
+
+def merge_responses(all_res, paginated_res, fields_to_keep=None, pagination_field=None):
+    if not pagination_field:
+        for key in all_res:
+            if all_res[key] != paginated_res.get(key, 0) and type(all_res[key]) == list:
+                pagination_field = key
+
+        if not pagination_field:  # should not happen
+            raise Exception("Failed to detect pagination_field")
+
+        # whitelist fields of the initial response
+        all_res[pagination_field] = whitelist_keys(all_res[pagination_field], fields_to_keep)
+
+    all_res[pagination_field] += whitelist_keys(paginated_res[pagination_field], fields_to_keep)
+
+    return all_res, pagination_field
+
+
+def normalize_list_params(params):
+    """
+    Normalizes parameters that could be provided as strings separated by ','.
+
+    >>> normalize_list_params(["f1,f2", "f3"])
+    ["f1", "f2", "f3"]
+
+    :param params: Params to normalize.
+    :type params: list
+
+    :return: A list of normalized params.
+    :rtype list
+    """
+    normalized_params = []
+    for f in list(params):
+        if "," in f:
+            normalized_params += f.split(",")
+        else:
+            normalized_params.append(f)
+
+    return normalized_params
